@@ -216,11 +216,13 @@ def volume_weighted_high_low_vol_cont(data = None,  contravariant = -1., lag = 2
     trend_lag = ((data['close'].iloc[-1]-data['close'].iloc[-2])/data['close'].iloc[-2])
     weighted_volu_hi_low_lag = data['volu_hi_low'].iloc[-1]/ data['volumefrom'].iloc[-1]
 
-    trend_ratio = trend_lag/trend
-    vol_ratio = weighted_volu_hi_low_lag/weighted_volu_hi_low
-
-    signal = contravariant * vol_ratio * trend_ratio
-
+    signal = np.nan
+    try:
+        trend_ratio = trend_lag/trend
+        vol_ratio = weighted_volu_hi_low_lag / weighted_volu_hi_low
+        signal = contravariant * vol_ratio * trend_ratio
+    except Exception as e:
+        print(e)
     return signal
 
 
